@@ -1,15 +1,10 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2005 Ismail Donmez <ismail@kde.org>
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
-  Copyright (C) 2007 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2005 Ismail Donmez <ismail@kde.org>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2007 Eike Hein <hein@kde.org>
 */
 
 #ifndef THEME_CONFIG_H
@@ -26,7 +21,7 @@ class Theme_Config : public QWidget, public KonviSettingsPage, private Ui::Theme
     Q_OBJECT
 
     public:
-        explicit Theme_Config(QWidget* parent, const char* name=NULL);
+        explicit Theme_Config(QWidget* parent, const char* name = nullptr);
         ~Theme_Config() override;
 
         void restorePageToDefaults() override;
@@ -38,11 +33,12 @@ class Theme_Config : public QWidget, public KonviSettingsPage, private Ui::Theme
     Q_SIGNALS:
         void modified();
 
-    protected Q_SLOTS:
+    private Q_SLOTS:
         void updatePreview(int id);
         void updateButtons();
         void installTheme();
         void removeTheme();
+        void gotNewSchemes();
         void postRemoveTheme(KJob* delete_job);
 
     private:
@@ -50,6 +46,8 @@ class Theme_Config : public QWidget, public KonviSettingsPage, private Ui::Theme
         QString m_oldTheme;
         QString m_currentTheme;
         int m_defaultThemeIndex;
+
+        Q_DISABLE_COPY(Theme_Config)
 };
 
 #endif
